@@ -3,7 +3,7 @@ package mixin::with;
 use strict;
 no strict 'refs';
 use vars qw($VERSION);
-$VERSION = 0.06;
+$VERSION = 0.07;
 
 =head1 NAME
 
@@ -102,12 +102,6 @@ sub __mixers {
 }
 
 
-sub _carp {
-    require Carp;
-    goto &Carp::carp;
-}
-
-
 =head1 FAQ
 
 =over 4
